@@ -96,7 +96,7 @@ def pm_quality(time, sector, camera, chip, pm=None):
 
         # Finds gap in orbits
         t = np.diff(time)
-        brk = np.where( t > np.mean(t)+2*np.std(t))[0][0]
+        brk = np.where( t == np.max(t))[0][0]
         brk += 1
 
         # Initiates lists for each orbit
@@ -150,11 +150,11 @@ def set_quality_flags(ffi_start, ffi_stop, shortCad_fn, sector, camera, chip,
     convolve_ffi = np.array(convolve_ffi)
 
     flags    = np.bitwise_and(convolve_ffi, ffi_apply)
-    pm_flags = pm_quality(ffi_stop, sector, camera, chip, pm=pm) * 4096
+    pm_flags = pm_quality(ffi_stop, sector, camera, chip, pm=pm) * 131072
 
-    pm_flags[ ((ffi_stop>1420.) & (ffi_stop < 1424.)) ] = 4096
+    pm_flags[ ((ffi_stop>1420.) & (ffi_stop < 1424.)) ] = 131072
 
-    return flags+pm_flags
+    return np.bitwise_or(flags, pm_flags)
 
 def centroid_quadratic(data, mask=None):
     """Computes the quadratic estimate of the centroid in a 2d-array.
