@@ -3,7 +3,8 @@ import matplotlib.pyplot as plt
 from astropy.nddata import Cutout2D
 from photutils import CircularAperture, RectangularAperture, aperture_photometry
 from photutils import MMMBackground
-from lightkurve import SFFCorrector, lightcurve
+from lightkurve import lightcurve
+from lightkurve.correctors import SFFCorrector
 from scipy.optimize import minimize
 from astropy import time, coordinates as coord, units as u
 from astropy.coordinates import SkyCoord, Angle
@@ -151,6 +152,7 @@ class TargetData(object):
                  language='English'):
         import eleanor
         self.source_info = source
+
         self.language = language
         self.pca_flux = None
         self.psf_flux = None
@@ -372,8 +374,6 @@ class TargetData(object):
             self.tpf_err[np.isnan(self.tpf_err)] = np.inf
 
 
-
-
         else:
             post_x_length, post_y_length = post_flux.shape[2], post_flux.shape[1]
             if (height > post_y_length) or (width > post_x_length):
@@ -1336,6 +1336,8 @@ class TargetData(object):
             information and all light curves except the optimal one selected
             by eleanor.
         """
+        import eleanor
+
         if self.language == 'Australian':
             raise ValueError("These light curves are upside down. Please don't save them ...")
 
@@ -1523,7 +1525,6 @@ class TargetData(object):
         self.best_ind = np.where(self.aperture_names == hdr['aperture'])[0][0]
 
 
-
         try:
             if self.source_info.tc == False:
                 if os.path.isfile(self.source_info.postcard_path) == True:
