@@ -66,7 +66,21 @@ def listFD(url, ext=''):
             node.get('href').endswith(ext)]
 
 
-__all__ = ['Update', 'update_all']
+__all__ = ['Update', 'update_all', 'update_max_sector']
+
+def update_max_sector():
+    baseurl = "https://archive.stsci.edu/missions/tess/ffi/"
+    
+    page = urlopen(baseurl)
+    read = page.read()
+    html = read.decode('utf-8').split('href="')
+    current_sectors = [i for i in html if 's00' in i]
+    sectors = [int(i[1:5]) for i in current_sectors]
+    
+    with open('maxsector.py', 'w') as tf:
+        tf.write('maxsector = {0}'.format(int(np.nanmax(sectors))))
+
+    print("Most recent sector available = ", int(np.nanmax(sectors)))
 
 
 def update_all():
@@ -90,6 +104,8 @@ class Update(object):
         if not os.path.exists(eleanorpath + '/metadata'):
             os.mkdir(eleanorpath + '/metadata')
 
+        # Updates max sector file first
+        update_max_sector()
 
         self.sector = sector
         self.metadata_path = os.path.join(eleanorpath, 'metadata/s{0:04d}'.format(self.sector))
@@ -106,21 +122,27 @@ class Update(object):
         self.south_coords = SkyCoord('04:35:50.330 -64:01:37.33',
                                      unit=(u.hourangle, u.deg))
 
+        self.ecliptic_coords_a = SkyCoord('04:00:00.000 +10:00:00.00',
+                                          unit=(u.hourangle, u.deg))
+        self.ecliptic_coords_b = SkyCoord('08:20:00.000 +12:00:00.00',
+                                          unit=(u.hourangle, u.deg))
 
-        if self.sector < 14 or self.sector > 26:
-            try:
-                manifest = Tesscut.download_cutouts(self.south_coords, 31, sector=self.sector)
-                success = 1
-            except:
-                print("This sector isn't available yet.")
-                return
+
+        if self.sector < 14 or (self.sector > 26 and self.sector < 40):
+            use_coords = self.south_coords
+        elif self.sector in [42, 43, 44]:
+            use_coords = self.ecliptic_coords_a
+        elif self.sector in [45, 46]:
+            use_coords = self.ecliptic_coords_b
         else:
-            try:
-                manifest = Tesscut.download_cutouts(self.north_coords, 31, sector=self.sector)
-                success = 1
-            except:
-                print("This sector isn't available yet.")
-                return
+            use_coords = self.north_coords
+
+        try:
+            manifest = Tesscut.download_cutouts(use_coords, 31, sector=self.sector)
+            success = 1
+        except:
+            print("This sector isn't available yet.")
+            return
 
         if success == 1:
             if os.path.isdir(self.metadata_path) == True:
@@ -156,8 +178,12 @@ class Update(object):
             year = 2018
         elif self.sector <= 20:
             year = 2019
-        else:
+        elif self.sector <= 33:
             year = 2020
+        elif self.sector <= 47:
+            year = 2021
+        else:
+            year = 2022
 
         url = 'https://archive.stsci.edu/missions/tess/ffi/s{0:04d}/{1}/'.format(self.sector, year)
 
